@@ -1,9 +1,23 @@
 from __future__ import unicode_literals, division, absolute_import
-from flexget.plugin import register_plugin, get_plugin_by_name, get_plugins_by_phase, PluginError
-from flexget.plugins.filter.series import FilterSeriesBase
+import hashlib
 import logging
 
+from sqlalchemy import Column, Integer, Unicode
+
+from flexget import db_schema
+from flexget.plugin import register_plugin, get_plugin_by_name, PluginError
+from flexget.plugins.filter.series import FilterSeriesBase
+
 log = logging.getLogger('import_series')
+Base = db_schema.versioned_base('import_series', 0)
+
+
+class LastHash(Base):
+    __tablename__ = 'import_series_last_hash'
+
+    id = Column(Integer, primary_key=True)
+    task = Column(Unicode)
+    hash = Column(Unicode)
 
 
 class ImportSeries(FilterSeriesBase):
@@ -58,6 +72,16 @@ class ImportSeries(FilterSeriesBase):
                 if entry.get('tvdb_id'):
                     s['set'] = {'tvdb_id': entry['tvdb_id']}
 
+        # Set the config_modified flag if the list of shows changed since last time
+        new_hash = hashlib.md5(unicode(sorted(series))).hexdigest().decode('ascii')
+        last_hash = task.session.query(LastHash).filter(LastHash.task == task.name).first()
+        if not last_hash:
+            last_hash = LastHash(task=task.name)
+            task.session.add(last_hash)
+        if last_hash.hash != new_hash:
+            task.config_changed()
+        last_hash.hash = new_hash
+
         if not series:
             log.info('Did not get any series to generate series configuration')
             return
